PushTokenData class

Push Token Data

Constructors

PushTokenData(Platforms platform, String token, MoEPushService pushService)
Push Token Related Data

Properties

hashCode int
The hash code for this object.
no setterinherited
platform Platforms
Type of Platform Android/IOS
getter/setter pair
pushService MoEPushService
Type of Push Service
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Push Token
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited